@@ -151,13 +151,13 @@ cache_dir = {
 
 usePP = False
 helper = None
-LISTPLACEMETHOD = ["jitter", "spheresBHT", "RAPID"]
+LISTPLACEMETHOD = ["jitter", "spheresBHT"]
 try:
     from panda3d.core import Mat4  # noqa: F401
 
-    LISTPLACEMETHOD = ["jitter", "spheresBHT", "pandaBullet", "RAPID"]
+    LISTPLACEMETHOD = ["jitter", "spheresBHT", "pandaBullet"]
 except ImportError:
-    LISTPLACEMETHOD = ["jitter", "spheresBHT", "RAPID"]
+    LISTPLACEMETHOD = ["jitter", "spheresBHT"]
 
 
 ncpus = 2
@@ -318,7 +318,6 @@ def updateReplacePath(newPaths):
 
 
 def retrieveFile(filename, destination="", cache="geometries", force=None):
-    #    helper = autopack.helper
     if force is None:
         force = forceFetch
     if filename.find("http") == -1 and filename.find("ftp") == -1:
